@@ -1,6 +1,7 @@
-var path = require("path");
+const path = require("path");
+
 module.exports = {
-	// mode: "development || "production",
+	// mode: "development" || "production",
 	entry: {
 		main: "./example"
 	},
