@@ -1,9 +1,10 @@
-var path = require("path");
-var webpack = require("../../");
+const path = require("path");
+const webpack = require("../../");
+
 module.exports = [
 	{
 		name: "vendor",
-		// mode: "development || "production",
+		// mode: "development" || "production",
 		entry: ["./vendor", "./vendor2"],
 		output: {
 			path: path.resolve(__dirname, "dist"),
@@ -20,7 +21,7 @@ module.exports = [
 
 	{
 		name: "app",
-		// mode: "development || "production",
+		// mode: "development" || "production",
 		dependencies: ["vendor"],
 		entry: {
 			pageA: "./pageA",
