@@ -105,6 +105,13 @@ class RuntimeTemplate {
 		return this.outputOptions.module;
 	}
 
+	isNeutralPlatform() {
+		return (
+			!this.outputOptions.environment.document &&
+			!this.compilation.compiler.platform.node
+		);
+	}
+
 	supportsConst() {
 		return this.outputOptions.environment.const;
 	}
