@@ -31,6 +31,7 @@ const builtins = [
 	"http2",
 	"https",
 	"inspector",
+	"inspector/promises",
 	"module",
 	"net",
 	"os",
@@ -42,8 +43,10 @@ const builtins = [
 	"punycode",
 	"querystring",
 	"readline",
+	"readline/promises",
 	"repl",
 	"stream",
+	"stream/consumers",
 	"stream/promises",
 	"stream/web",
 	"string_decoder",
