@@ -10,9 +10,17 @@ const EnableChunkLoadingPlugin = require("../javascript/EnableChunkLoadingPlugin
 
 /** @typedef {import("../Compiler")} Compiler */
 
+/**
+ * @typedef {object} NodeTemplatePluginOptions
+ * @property {boolean} [asyncChunkLoading] enable async chunk loading
+ */
+
 class NodeTemplatePlugin {
-	constructor(options) {
-		this._options = options || {};
+	/**
+	 * @param {NodeTemplatePluginOptions} [options] options object
+	 */
+	constructor(options = {}) {
+		this._options = options;
 	}
 
 	/**
