@@ -5,10 +5,16 @@
 
 "use strict";
 
+/** @typedef {import("../../declarations/WebpackOptions").RuleSetRule} RuleSetRule */
 /** @typedef {import("./RuleSetCompiler")} RuleSetCompiler */
 /** @typedef {import("./RuleSetCompiler").RuleCondition} RuleCondition */
 
 class BasicMatcherRulePlugin {
+	/**
+	 * @param {string} ruleProperty the rule property
+	 * @param {string=} dataProperty the data property
+	 * @param {boolean=} invert if true, inverts the condition
+	 */
 	constructor(ruleProperty, dataProperty, invert) {
 		this.ruleProperty = ruleProperty;
 		this.dataProperty = dataProperty || ruleProperty;
@@ -25,7 +31,8 @@ class BasicMatcherRulePlugin {
 			(path, rule, unhandledProperties, result) => {
 				if (unhandledProperties.has(this.ruleProperty)) {
 					unhandledProperties.delete(this.ruleProperty);
-					const value = rule[this.ruleProperty];
+					const value =
+						rule[/** @type {keyof RuleSetRule} */ (this.ruleProperty)];
 					const condition = ruleSetCompiler.compileCondition(
 						`${path}.${this.ruleProperty}`,
 						value
