@@ -7,19 +7,23 @@
 const RuntimeGlobals = require("../RuntimeGlobals");
 const RuntimeModule = require("../RuntimeModule");
 
+/** @typedef {import("../Compilation")} Compilation */
 /** @typedef {import("../MainTemplate")} MainTemplate */
 
 class StartupEntrypointRuntimeModule extends RuntimeModule {
+	/**
+	 * @param {boolean} asyncChunkLoading use async chunk loading
+	 */
 	constructor(asyncChunkLoading) {
 		super("startup entrypoint");
 		this.asyncChunkLoading = asyncChunkLoading;
 	}
 
 	/**
-	 * @returns {string} runtime code
+	 * @returns {string | null} runtime code
 	 */
 	generate() {
-		const { compilation } = this;
+		const compilation = /** @type {Compilation} */ (this.compilation);
 		const { runtimeTemplate } = compilation;
 		return `${
 			RuntimeGlobals.startupEntrypoint
@@ -27,22 +31,22 @@ class StartupEntrypointRuntimeModule extends RuntimeModule {
 			"// arguments: chunkIds, moduleId are deprecated",
 			"var moduleId = chunkIds;",
 			`if(!fn) chunkIds = result, fn = ${runtimeTemplate.returningFunction(
-				`__webpack_require__(${RuntimeGlobals.entryModuleId} = moduleId)`
+				`${RuntimeGlobals.require}(${RuntimeGlobals.entryModuleId} = moduleId)`
 			)};`,
 			...(this.asyncChunkLoading
 				? [
-						`return Promise.all(chunkIds.map(${
-							RuntimeGlobals.ensureChunk
-						}, __webpack_require__)).then(${runtimeTemplate.basicFunction("", [
+						`return Promise.all(chunkIds.map(${RuntimeGlobals.ensureChunk}, ${
+							RuntimeGlobals.require
+						})).then(${runtimeTemplate.basicFunction("", [
 							"var r = fn();",
 							"return r === undefined ? result : r;"
 						])})`
-				  ]
+					]
 				: [
-						`chunkIds.map(${RuntimeGlobals.ensureChunk}, __webpack_require__)`,
+						`chunkIds.map(${RuntimeGlobals.ensureChunk}, ${RuntimeGlobals.require})`,
 						"var r = fn();",
 						"return r === undefined ? result : r;"
-				  ])
+					])
 		])}`;
 	}
 }
