@@ -336,7 +336,6 @@ describe("snapshots", () => {
 		    "crossOriginLoading": false,
 		    "cssChunkFilename": "[name].css",
 		    "cssFilename": "[name].css",
-		    "cssHeadDataCompression": true,
 		    "devtoolFallbackModuleFilenameTemplate": undefined,
 		    "devtoolModuleFilenameTemplate": undefined,
 		    "devtoolNamespace": "webpack",
@@ -860,9 +859,6 @@ describe("snapshots", () => {
 		-       "minRemainingSize": undefined,
 		+       "minRemainingSize": 0,
 		@@ ... @@
-		-     "cssHeadDataCompression": true,
-		+     "cssHeadDataCompression": false,
-		@@ ... @@
 		-     "pathinfo": false,
 		+     "pathinfo": true,
 		@@ ... @@
@@ -1923,9 +1919,6 @@ describe("snapshots", () => {
 			-       "minRemainingSize": undefined,
 			+       "minRemainingSize": 0,
 			@@ ... @@
-			-     "cssHeadDataCompression": true,
-			+     "cssHeadDataCompression": false,
-			@@ ... @@
 			-     "pathinfo": false,
 			+     "pathinfo": true,
 			@@ ... @@
@@ -2329,9 +2322,8 @@ describe("snapshots", () => {
 			+         "resolve": Object {
 			+           "fullySpecified": true,
 			+           "preferRelative": true,
-			@@ ... @@
+			+         },
 			+         "type": "css",
-			+       },
 			@@ ... @@
 			-     "generator": Object {},
 			+     "generator": Object {
@@ -2353,9 +2345,11 @@ describe("snapshots", () => {
 			+       },
 			+     },
 			@@ ... @@
-			+       },
 			+       "css": Object {
+			+         "import": true,
 			+         "namedExports": true,
+			+         "url": true,
+			+       },
 			@@ ... @@
 			+         "exportsPresence": "error",
 			@@ ... @@
@@ -2373,6 +2367,9 @@ describe("snapshots", () => {
 			+     "hashDigestLength": 16,
 			+     "hashFunction": "xxhash64",
 			@@ ... @@
+			+           "...",
+			+         ],
+			+       },
 			+       "css-import": Object {
 			+         "conditionNames": Array [
 			+           "webpack",
@@ -2384,11 +2381,9 @@ describe("snapshots", () => {
 			+         ],
 			+         "mainFields": Array [
 			+           "style",
-			+           "...",
-			+         ],
+			@@ ... @@
 			+         "mainFiles": Array [],
 			+         "preferRelative": true,
-			+       },
 			@@ ... @@
 			-       "<cwd>/node_modules/",
 			+       /^(.+?[\\\\/]node_modules[\\\\/])/,
