@@ -1,4 +1,4 @@
-import {mixin1, mixin2, mixin3, A, B, C, Y} from "./dep2";
+import {mixin1, mixin2, mixin3, getField, A, B, C, Y, mixin4} from "./dep2";
 
 export const A1 = class A1 extends A {
 	render() {return new E();}
@@ -12,7 +12,7 @@ export const C1 = class C1 extends mixin2(Y, /*#__PURE__*/ mixin3(C)) {
 	render() {return new D();}
 };
 
-export class Y1 extends mixin2(Y) {
+export class Y1 extends /*#__PURE__*/ mixin2(Y) {
 	constructor() {
 		super();
 
@@ -22,5 +22,9 @@ export class Y1 extends mixin2(Y) {
 	render() {return new D();}
 }
 
+export class Bar extends /*#__PURE__*/ mixin4(A) {
+	[/*#__PURE__*/ getField()] = 12;
+}
+
 export class E {}
 const D = class D {};
