@@ -1,5 +1,5 @@
-import { A, B, getC, getD, getE, getF } from "./dep2?expr";
-import { A3, B3, C3, D3, E3, F3 } from "./dep3?expr";
+import {A, B, DateFormatter, getC, getD, getE, getF, Pure, ConditionalExpression, LogicalExpression} from "./dep2?expr";
+import { A3, B3, C3, D3, E3, F3, Pure3} from "./dep3?expr";
 
 export const A1 = class extends A {
 	render() {
@@ -39,6 +39,31 @@ export const F1 = class extends getF() {
 	}
 };
 
+export const ExtendsPure = class extends Pure {
+	render() {
+		return new Pure3();
+	}
+};
+
+export class DateBar extends DateFormatter {
+	constructor() {
+		super();
+	}
+	render() {}
+}
+
+export class ConditionalExpression1 extends ConditionalExpression {
+	render() {
+		return new ConditionalExpression3();
+	}
+}
+
+export class LogicalExpression1 extends LogicalExpression {
+	render() {
+		return new LogicalExpression3();
+	}
+}
+
 export const A2 = class extends A3 {};
 export const B2 = class extends B3 {};
 export const C2 = class extends C3 {};
