@@ -4,8 +4,8 @@ it("should load a utf-8 file with BOM", function () {
 });
 
 it("should load a css file with BOM", function () {
-	var css = require("!css-loader?sourceMap=false!./bomfile.css").default + "";
-	expect(css).toBe("body{color:#abc}");
+	var css = require("!css-loader!./bomfile.css").default + "";
+	expect(css.replace(/\n\/\*[\s\S]*?\*\/|([^\\:]|^)\/\/.*$/gm, '$1')).toBe("body{color:#abc}");
 });
 
 it("should load a json file with BOM", function () {
