@@ -1,5 +1,5 @@
 /** @type {import("../../../../").WebpackPluginFunction} */
-var testPlugin = function () {
+function testPlugin() {
 	var counter = 1;
 	this.hooks.compilation.tap("TestPlugin", compilation => {
 		var nr = counter++;
@@ -7,7 +7,7 @@ var testPlugin = function () {
 			if (nr < 5) return true;
 		});
 	});
-};
+}
 
 /** @type {import("../../../../").Configuration} */
 module.exports = {
