@@ -7,9 +7,8 @@ module.exports = {
 				test: /\.(png|svg|jpg)$/,
 				type: "asset",
 				parser: {
-					dataUrlCondition: (source, { filename, module }) => {
-						return filename.includes("?foo=bar");
-					}
+					dataUrlCondition: (source, { filename, module }) =>
+						filename.includes("?foo=bar")
 				}
 			}
 		]
