@@ -5,9 +5,7 @@ module.exports = {
 			async get(module) {
 				const testFactory = await ss.test[Object.keys(ss.test)[0]].get();
 				const test = testFactory();
-				return () => {
-					return test(module);
-				};
+				return () => test(module);
 			},
 			async init(shareScope) {
 				ss = shareScope;
