@@ -11,7 +11,7 @@ module.exports = {
 			get(module) {
 				return new Promise(resolve => {
 					setTimeout(() => {
-						resolve(() => "abc " + module);
+						resolve(() => `abc ${module}`);
 					}, 100);
 				});
 			}
