@@ -10,5 +10,8 @@ module.exports = {
 	},
 	optimization: {
 		minimize: false
+	},
+	experiments: {
+		css: true
 	}
 };
