@@ -7,12 +7,19 @@ module.exports = {
 				expect(compilation.outputOptions.environment).toMatchInlineSnapshot(`
 			Object {
 			  "arrowFunction": false,
+			  "asyncFunction": false,
 			  "bigIntLiteral": false,
 			  "const": false,
 			  "destructuring": false,
+			  "document": true,
 			  "dynamicImport": false,
+			  "dynamicImportInWorker": false,
 			  "forOf": false,
+			  "globalThis": false,
 			  "module": false,
+			  "nodePrefixForCoreModules": false,
+			  "optionalChaining": false,
+			  "templateLiteral": false,
 			}
 		`);
 				expect(compilation.options.externalsPresets).toMatchInlineSnapshot(`
