@@ -1,14 +1,14 @@
 const System = require("../../../helpers/fakeSystem");
 
 module.exports = {
-	target: 'web',
+	target: "web",
 	beforeExecute: () => {
 		System.init();
 	},
 	moduleScope(scope) {
-		scope.window.windowExt = 'works';
-		scope.rootExt = 'works';
-		scope.varExt = 'works';
+		scope.window.windowExt = "works";
+		scope.rootExt = "works";
+		scope.varExt = "works";
 		scope.System = System;
 	},
 	afterExecute: () => {
