@@ -7,16 +7,16 @@ module.exports = [
 	{
 		name: "development",
 		mode: "development",
-		plugins: [new DefinePlugin({ __MODE__: `"development"` })]
+		plugins: [new DefinePlugin({ __MODE__: '"development"' })]
 	},
 	{
 		name: "production",
 		mode: "production",
-		plugins: [new DefinePlugin({ __MODE__: `"production"` })]
+		plugins: [new DefinePlugin({ __MODE__: '"production"' })]
 	},
 	{
 		name: "none",
 		mode: "none",
-		plugins: [new DefinePlugin({ __MODE__: `"none"` })]
+		plugins: [new DefinePlugin({ __MODE__: '"none"' })]
 	}
 ];
