@@ -1,9 +1,9 @@
-var fs = require('fs');
+var fs = require("fs");
 
 module.exports = {
 	noTests: true,
-	findBundle: function(i, options) {
-		var regex = new RegExp("^bundle\." + options.name, "i");
+	findBundle: function (i, options) {
+		var regex = new RegExp(`^bundle.${options.name}`, "i");
 		var files = fs.readdirSync(options.output.path);
 		var bundle = files.find(function (file) {
 			return regex.test(file);
@@ -17,6 +17,6 @@ module.exports = {
 			);
 		}
 
-		return "./" + bundle;
+		return `./${bundle}`;
 	}
 };
