@@ -165,6 +165,45 @@ module.exports = (env, { testPath }) => [
 			})
 		]
 	},
+	{
+		resolve: {
+			alias: {
+				library: path.resolve(testPath, "../0-create-library/true-iife-umd.js")
+			}
+		},
+		plugins: [
+			new webpack.DefinePlugin({
+				NAME: JSON.stringify("true-iife-umd")
+			})
+		]
+	},
+	{
+		resolve: {
+			alias: {
+				library: path.resolve(testPath, "../0-create-library/false-iife-umd.js")
+			}
+		},
+		plugins: [
+			new webpack.DefinePlugin({
+				NAME: JSON.stringify("false-iife-umd")
+			})
+		]
+	},
+	{
+		resolve: {
+			alias: {
+				library: path.resolve(
+					testPath,
+					"../0-create-library/false-iife-umd2.js"
+				)
+			}
+		},
+		plugins: [
+			new webpack.DefinePlugin({
+				NAME: JSON.stringify("false-iife-umd2")
+			})
+		]
+	},
 	{
 		entry: "./this-test.js",
 		resolve: {
