@@ -4,5 +4,5 @@ it("should name define", function() {
 	var fs = require("fs");
 	var source = fs.readFileSync(__filename, "utf-8");
 
-	expect(source).toMatch(/define\(\[[^\]]*\], (function)?\(/);
+	expect(source).toMatch(/define\((function)?\(/);
 });
