@@ -11,7 +11,7 @@ module.exports = {
 	plugins: [
 		new webpack.BannerPlugin({
 			raw: true,
-			banner: "function define(deps, fn) { fn(); }\n"
+			banner: "function define(fn) { fn(); }\n"
 		})
 	]
 };
