@@ -1,5 +1,5 @@
 module.exports = () => {
-	let warnings = [];
+	const warnings = [];
 	let oldWarn;
 
 	beforeEach(done => {
