@@ -2,7 +2,7 @@ module.exports = function supportsES6() {
 	try {
 		eval("class A { #field = 1 }");
 		return true;
-	} catch (e) {
+	} catch (_err) {
 		return false;
 	}
 };
