@@ -4,7 +4,7 @@ module.exports = function supportsLogicalAssignment() {
 			"(function f() { var x = null; x ??= true; x &&= true; return x ||= false; })"
 		);
 		return f();
-	} catch (e) {
+	} catch (_err) {
 		return false;
 	}
 };
