@@ -2,7 +2,7 @@ module.exports = function supportsOptionalChaining() {
 	try {
 		var f = eval("(function f() { return ({a: true}) ?.a })");
 		return f();
-	} catch (e) {
+	} catch (_err) {
 		return false;
 	}
 };
