@@ -1,7 +1,7 @@
 describe("warmup", () => {
 	it("should warmup webpack", done => {
 		let webpack = require("../../");
-		let END = new Error("end warmup");
+		const END = new Error("end warmup");
 		webpack(
 			{
 				entry: "data:text/javascript,import 'data:text/javascript,'",
@@ -17,8 +17,8 @@ describe("warmup", () => {
 				try {
 					expect(err).toBe(END);
 					done();
-				} catch (e) {
-					done(e);
+				} catch (doneErr) {
+					done(doneErr);
 				}
 			}
 		);
