@@ -8,5 +8,5 @@ module.exports = {
 		hashDigestLength: 4
 	},
 	plugins: [new webpack.HotModuleReplacementPlugin()],
-	recordsPath: __dirname + "/records.json" // this is not required for the webpack-dev-server, but when compiled.
+	recordsPath: `${__dirname}/records.json` // this is not required for the webpack-dev-server, but when compiled.
 };
